netapp_ontap.models.aggregate_block_storage API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.aggregate_block_storage`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AggregateBlockStorageSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AggregateBlockStorage object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `hybrid_cache GET POST PATCH`

    The hybrid_cache field of the aggregate_block_storage.

  `mirror GET POST PATCH`

    The mirror field of the aggregate_block_storage.

  `plexes GET`

    Plex reference for each plex in the aggregate.

  `primary GET POST PATCH`

    The primary field of the aggregate_block_storage.